@@ -1,32 +1,28 @@
 package HTML::SocialMeta;
-use Moose;
-use namespace::autoclean;
+use Moo;
 use List::MoreUtils qw(uniq);
 
 use HTML::SocialMeta::Twitter;
 use HTML::SocialMeta::OpenGraph;
 
-our $VERSION = '0.5';
+our $VERSION = '0.7';
 
-has 'card_type' => ( isa => 'Str', is => 'rw', lazy => 1, default => q{} );
+has 'card_type' => ( is => 'rw', lazy => 1, default => q{} );
 has [
     qw(card site site_name title description image url creator operatingSystem app_country app_name app_id app_url player player_height player_width fb_app_id)
   ] => (
     is      => 'ro',
-    isa     => 'Str',
     lazy    => 1,
     default => q{},
   );
 
 has 'twitter' => (
-    isa     => 'HTML::SocialMeta::Twitter',
     is      => 'ro',
     lazy    => 1,
     builder => 'build_twitter',
 );
 
 has 'opengraph' => (
-    isa     => 'HTML::SocialMeta::OpenGraph',
     is      => 'ro',
     lazy    => 1,
     builder => 'build_opengraph',
@@ -114,7 +110,7 @@ HTML::SocialMeta - Module to generate Social Media Meta Tags,
 
 =head1 VERSION
 
-Version 0.5
+Version 0.7
 
 =head1 SYNOPSIS
 
@@ -207,7 +203,7 @@ OPTIONAL - if you always want the same card type you can set it
 
 The Twitter @username the card should be attributed to. Required for Twitter Card analytics. 
 
-=item site name
+=item site_name
 
 This is Used by Facebook, you can just set it as your organisations name.
 
@@ -438,8 +434,7 @@ Add support for additional card types
 
 =head1 DEPENDENCIES
 
-Moose - Version 2.0604
-Namespace::Autoclean - Verstion 0.15
+Moo - Version 1.001000, 
 List::MoreUtils - Version 0.413 
 
 =head1 DIAGNOSTICS
@@ -479,7 +474,7 @@ Robert Haliday <robh@cpan.org>
 
 =head1 LICENSE AND COPYRIGHT
  
-Copyright 2015 Robert Acock.
+Copyright 2016 Robert Acock.
  
 This program is free software; you can redistribute it and/or modify it
 under the terms of the the Artistic License (2.0). You may obtain a
