@@ -1,19 +1,15 @@
 package HTML::SocialMeta::OpenGraph;
-use Moose;
-use namespace::autoclean;
+use Moo;
 use Carp;
-
-our $VERSION = '0.5';
+our $VERSION = '0.7';
 
 extends 'HTML::SocialMeta::Base';
 
 # Provider Specific Fields
-has 'meta_attribute' =>
-  ( isa => 'Str', is => 'ro', required => 1, default => 'property' );
-has 'meta_namespace' =>
-  ( isa => 'Str', is => 'ro', required => 1, default => 'og' );
+has 'meta_attribute' => ( is => 'ro', default => 'property' );
+has 'meta_namespace' => ( is => 'ro', default => 'og' );
 
-has 'fb_namespace' => ( isa => 'Str', is => 'rw', lazy => 1, default => q{} );
+has 'fb_namespace' => ( is => 'rw', lazy => 1, default => q{} );
 
 has '+card_options' => (
     default => sub {
@@ -76,8 +72,9 @@ sub create_product {
 sub provider_convert {
     my ( $self, $field ) = @_;
 
-    if ( $field =~ m{^fb:}xms ) {
-        $field =~ s{^fb:}{}xms;
+    if ( $field =~ s{^fb:}{}xms ) {
+        $field =~ s{:}{_}xms;
+        
         return [ { field_type => $field, ignore_meta_namespace => 'fb' } ];
     }
 
@@ -107,7 +104,7 @@ HTML::SocialMeta::OpenGraph
 
 =head1 VERSION
 
-Version 0.5
+Version 0.7
 
 =cut
 
